@@ -2,9 +2,9 @@ from typing import Tuple
 
 import pandas as pd
 
-from evidently.calculations.stattests.registry import StatTest
-from evidently.calculations.stattests.registry import register_stattest
-from evidently.utils.data_drift_utils import calculate_text_drift_score
+from mlopsdna.evidently.calculations.stattests.registry import StatTest
+from mlopsdna.evidently.calculations.stattests.registry import register_stattest
+from mlopsdna.evidently.utils.data_drift_utils import calculate_text_drift_score
 
 
 def _text_content_drift(
