@@ -1,10 +1,10 @@
 #!/usr/bin/env python
 # coding: utf-8
-from evidently.dashboard.tabs.base_tab import Tab
-from evidently.dashboard.tabs.base_tab import Verbose
-from evidently.dashboard.widgets.cat_output_drift_widget import CatOutputDriftWidget
-from evidently.dashboard.widgets.cat_target_pred_feature_table_widget import CatTargetPredFeatureTable
-from evidently.dashboard.widgets.prob_class_pred_distr_widget import ProbClassPredDistrWidget
+from mlopsdna.evidently.dashboard.tabs.base_tab import Tab
+from mlopsdna.evidently.dashboard.tabs.base_tab import Verbose
+from mlopsdna.evidently.dashboard.widgets.cat_output_drift_widget import CatOutputDriftWidget
+from mlopsdna.evidently.dashboard.widgets.cat_target_pred_feature_table_widget import CatTargetPredFeatureTable
+from mlopsdna.evidently.dashboard.widgets.prob_class_pred_distr_widget import ProbClassPredDistrWidget
 
 
 class CatTargetDriftTab(Tab):
