@@ -10,14 +10,14 @@ import pandas as pd
 import plotly.graph_objects as go
 from plotly.subplots import make_subplots
 
-from evidently import ColumnMapping
-from evidently.analyzers.data_quality_analyzer import DataQualityAnalyzer
-from evidently.analyzers.data_quality_analyzer import DataQualityAnalyzerResults
-from evidently.calculations.data_quality import FeatureQualityStats
-from evidently.dashboard.widgets.widget import Widget
-from evidently.model.widget import AdditionalGraphInfo
-from evidently.model.widget import BaseWidgetInfo
-from evidently.options import ColorOptions
+from mlopsdna.evidently import ColumnMapping
+from mlopsdna.evidently.analyzers.data_quality_analyzer import DataQualityAnalyzer
+from mlopsdna.evidently.analyzers.data_quality_analyzer import DataQualityAnalyzerResults
+from mlopsdna.evidently.calculations.data_quality import FeatureQualityStats
+from mlopsdna.evidently.dashboard.widgets.widget import Widget
+from mlopsdna.evidently.model.widget import AdditionalGraphInfo
+from mlopsdna.evidently.model.widget import BaseWidgetInfo
+from mlopsdna.evidently.options import ColorOptions
 
 
 class DataQualityFeaturesWidget(Widget):
