@@ -9,11 +9,11 @@ import plotly.express as px
 import plotly.graph_objs as go
 from plotly.subplots import make_subplots
 
-from evidently import ColumnMapping
-from evidently.analyzers.regression_performance_analyzer import RegressionPerformanceAnalyzer
-from evidently.dashboard.widgets.widget import Widget
-from evidently.model.widget import AdditionalGraphInfo
-from evidently.model.widget import BaseWidgetInfo
+from mlopsdna.evidently import ColumnMapping
+from mlopsdna.evidently.analyzers.regression_performance_analyzer import RegressionPerformanceAnalyzer
+from mlopsdna.evidently.dashboard.widgets.widget import Widget
+from mlopsdna.evidently.model.widget import AdditionalGraphInfo
+from mlopsdna.evidently.model.widget import BaseWidgetInfo
 
 
 def _error_bias_string(quantile_5, quantile_95):
