@@ -1,6 +1,6 @@
-from evidently.features import non_letter_character_percentage_feature
-from evidently.features.generated_features import FeatureDescriptor
-from evidently.features.generated_features import GeneratedFeature
+from mlopsdna.evidently.features import non_letter_character_percentage_feature
+from mlopsdna.evidently.features.generated_features import FeatureDescriptor
+from mlopsdna.evidently.features.generated_features import GeneratedFeature
 
 
 class NonLetterCharacterPercentage(FeatureDescriptor):
