@@ -11,7 +11,7 @@ from typing import Union
 
 import pandas as pd
 
-import mlopsdna.evidently
+import mlopsdna.evidently as evidently
 from mlopsdna.evidently.base_metric import ErrorResult
 from mlopsdna.evidently.base_metric import InputData
 from mlopsdna.evidently.base_metric import Metric
