@@ -7,37 +7,37 @@ from typing import Union
 import numpy as np
 import pandas as pd
 
-from evidently.calculations.data_quality import get_corr_method
-from evidently.metrics import ColumnQuantileMetric
-from evidently.metrics import ColumnSummaryMetric
-from evidently.metrics import ColumnValueListMetric
-from evidently.metrics import ColumnValueRangeMetric
-from evidently.metrics import ConflictPredictionMetric
-from evidently.metrics import ConflictTargetMetric
-from evidently.metrics import DatasetCorrelationsMetric
-from evidently.metrics.data_integrity.column_summary_metric import NumericCharacteristics
-from evidently.metrics.data_integrity.column_summary_metric import TextCharacteristics
-from evidently.renderers.base_renderer import TestHtmlInfo
-from evidently.renderers.base_renderer import TestRenderer
-from evidently.renderers.base_renderer import default_renderer
-from evidently.renderers.html_widgets import plotly_figure
-from evidently.renderers.render_utils import get_distribution_plot_figure
-from evidently.renderers.render_utils import plot_distr
-from evidently.tests.base_test import BaseCheckValueTest
-from evidently.tests.base_test import GroupData
-from evidently.tests.base_test import GroupingTypes
-from evidently.tests.base_test import Test
-from evidently.tests.base_test import TestResult
-from evidently.tests.base_test import TestValueCondition
-from evidently.tests.utils import approx
-from evidently.tests.utils import plot_check
-from evidently.tests.utils import plot_correlations
-from evidently.tests.utils import plot_metric_value
-from evidently.tests.utils import plot_value_counts_tables
-from evidently.tests.utils import plot_value_counts_tables_ref_curr
-from evidently.utils.data_operations import DatasetColumns
-from evidently.utils.generators import BaseGenerator
-from evidently.utils.types import Numeric
+from mlopsdna.evidently.calculations.data_quality import get_corr_method
+from mlopsdna.evidently.metrics import ColumnQuantileMetric
+from mlopsdna.evidently.metrics import ColumnSummaryMetric
+from mlopsdna.evidently.metrics import ColumnValueListMetric
+from mlopsdna.evidently.metrics import ColumnValueRangeMetric
+from mlopsdna.evidently.metrics import ConflictPredictionMetric
+from mlopsdna.evidently.metrics import ConflictTargetMetric
+from mlopsdna.evidently.metrics import DatasetCorrelationsMetric
+from mlopsdna.evidently.metrics.data_integrity.column_summary_metric import NumericCharacteristics
+from mlopsdna.evidently.metrics.data_integrity.column_summary_metric import TextCharacteristics
+from mlopsdna.evidently.renderers.base_renderer import TestHtmlInfo
+from mlopsdna.evidently.renderers.base_renderer import TestRenderer
+from mlopsdna.evidently.renderers.base_renderer import default_renderer
+from mlopsdna.evidently.renderers.html_widgets import plotly_figure
+from mlopsdna.evidently.renderers.render_utils import get_distribution_plot_figure
+from mlopsdna.evidently.renderers.render_utils import plot_distr
+from mlopsdna.evidently.tests.base_test import BaseCheckValueTest
+from mlopsdna.evidently.tests.base_test import GroupData
+from mlopsdna.evidently.tests.base_test import GroupingTypes
+from mlopsdna.evidently.tests.base_test import Test
+from mlopsdna.evidently.tests.base_test import TestResult
+from mlopsdna.evidently.tests.base_test import TestValueCondition
+from mlopsdna.evidently.tests.utils import approx
+from mlopsdna.evidently.tests.utils import plot_check
+from mlopsdna.evidently.tests.utils import plot_correlations
+from mlopsdna.evidently.tests.utils import plot_metric_value
+from mlopsdna.evidently.tests.utils import plot_value_counts_tables
+from mlopsdna.evidently.tests.utils import plot_value_counts_tables_ref_curr
+from mlopsdna.evidently.utils.data_operations import DatasetColumns
+from mlopsdna.evidently.utils.generators import BaseGenerator
+from mlopsdna.evidently.utils.types import Numeric
 
 DATA_QUALITY_GROUP = GroupData("data_quality", "Data Quality", "")
 GroupingTypes.TestGroup.add_value(DATA_QUALITY_GROUP)
