@@ -9,12 +9,12 @@ import plotly.graph_objs as go
 from pandas.api.types import is_numeric_dtype
 from plotly.subplots import make_subplots
 
-from evidently.model.widget import BaseWidgetInfo
-from evidently.options import ColorOptions
-from evidently.renderers.base_renderer import DetailsInfo
-from evidently.renderers.html_widgets import plotly_figure
-from evidently.renderers.html_widgets import table_data
-from evidently.utils.types import ApproxValue
+from mlopsdna.evidently.model.widget import BaseWidgetInfo
+from mlopsdna.evidently.options import ColorOptions
+from mlopsdna.evidently.renderers.base_renderer import DetailsInfo
+from mlopsdna.evidently.renderers.html_widgets import plotly_figure
+from mlopsdna.evidently.renderers.html_widgets import table_data
+from mlopsdna.evidently.utils.types import ApproxValue
 
 
 def plot_check(fig, condition, color_options: ColorOptions):
