@@ -9,7 +9,7 @@ from typing import Dict
 from typing import List
 from typing import Optional
 
-import mlopsdna.evidently
+import mlopsdna.evidently as evidently
 from mlopsdna.evidently.model.dashboard import DashboardInfo
 from mlopsdna.evidently.utils import NumpyEncoder
 
